@@ -1,6 +1,8 @@
 """Setup command for mcp-ticketer - smart initialization with platform detection."""
 
 import json
+import subprocess
+import sys
 from pathlib import Path
 
 import typer
@@ -8,6 +10,121 @@ from rich.console import Console
 
 console = Console()
 
+# Mapping of adapter types to their required dependencies
+ADAPTER_DEPENDENCIES = {
+    "linear": {"package": "gql[httpx]", "extras": "linear"},
+    "jira": {"package": "jira", "extras": "jira"},
+    "github": {"package": "PyGithub", "extras": "github"},
+    "aitrackdown": None,  # No extra dependencies
+}
+
+
+def _check_package_installed(adapter_type: str) -> bool:
+    """Check if adapter-specific package is installed.
+
+    Args:
+        adapter_type: Type of adapter (linear, jira, github)
+
+    Returns:
+        True if package is installed, False otherwise
+
+    """
+    try:
+        # Try to import the package
+        if adapter_type == "linear":
+            import gql  # noqa: F401
+        elif adapter_type == "jira":
+            import jira  # noqa: F401
+        elif adapter_type == "github":
+            import github  # noqa: F401
+        return True
+    except ImportError:
+        return False
+
+
+def _check_and_install_adapter_dependencies(
+    adapter_type: str, console: Console
+) -> bool:
+    """Check if adapter-specific dependencies are installed and offer to install.
+
+    Args:
+        adapter_type: Type of adapter (linear, jira, github, aitrackdown)
+        console: Rich console for output
+
+    Returns:
+        True if dependencies are satisfied (installed or not needed), False if failed
+
+    """
+    # Check if adapter needs extra dependencies
+    dependency_info = ADAPTER_DEPENDENCIES.get(adapter_type)
+
+    if dependency_info is None:
+        # No extra dependencies needed (e.g., aitrackdown)
+        console.print(
+            f"[green]✓[/green] No extra dependencies required for {adapter_type}\n"
+        )
+        return True
+
+    # Check if the required package is already installed
+    if _check_package_installed(adapter_type):
+        console.print(
+            f"[green]✓[/green] {adapter_type.capitalize()} dependencies already installed\n"
+        )
+        return True
+
+    # Dependencies not installed
+    console.print(
+        f"[yellow]⚠[/yellow]  {adapter_type.capitalize()} adapter requires additional dependencies\n"
+    )
+    console.print(f"[dim]Required package: {dependency_info['package']}[/dim]\n")
+
+    # Prompt user to install
+    try:
+        if not typer.confirm("Install dependencies now?", default=True):
+            console.print(
+                "\n[yellow]Skipping installation. Install manually with:[/yellow]"
+            )
+            console.print(
+                f"[cyan]  pip install mcp-ticketer[{dependency_info['extras']}][/cyan]\n"
+            )
+            return True  # User declined, but we continue
+
+    except typer.Abort:
+        console.print("\n[yellow]Installation cancelled[/yellow]\n")
+        return True
+
+    # Install dependencies
+    console.print(f"[cyan]Installing {adapter_type} dependencies...[/cyan]\n")
+
+    try:
+        # Run pip install with the extras
+        subprocess.check_call(
+            [
+                sys.executable,
+                "-m",
+                "pip",
+                "install",
+                f"mcp-ticketer[{dependency_info['extras']}]",
+            ],
+            stdout=subprocess.DEVNULL,
+            stderr=subprocess.PIPE,
+        )
+
+        console.print(
+            f"[green]✓[/green] Successfully installed {adapter_type} dependencies\n"
+        )
+        return True
+
+    except subprocess.CalledProcessError as e:
+        console.print(
+            f"[red]✗[/red] Failed to install dependencies: {e.stderr.decode() if e.stderr else 'Unknown error'}\n"
+        )
+        console.print("[yellow]Please install manually with:[/yellow]")
+        console.print(
+            f"[cyan]  pip install mcp-ticketer[{dependency_info['extras']}][/cyan]\n"
+        )
+        return True  # Continue even if installation failed
+
 
 def _prompt_for_adapter_selection(console: Console) -> str:
     """Interactive prompt for adapter selection.
@@ -117,8 +234,6 @@ def setup(
     Note: For advanced configuration, use 'init' and 'install' separately.
 
     """
-    # Import init from main to avoid circular dependency
-    from .main import init
     from .platform_detection import PlatformDetector
 
     proj_path = Path(project_path) if project_path else Path.cwd()
@@ -167,6 +282,7 @@ def setup(
         # Run init command non-interactively through function call
         # We'll use the discover and prompt flow from init
         from ..core.env_discovery import discover_config
+        from .init_command import _init_adapter_internal
 
         discovered = discover_config(proj_path)
         adapter_type = None
@@ -192,13 +308,20 @@ def setup(
         # Now run the full init with the selected adapter
         console.print(f"\n[cyan]Initializing {adapter_type} adapter...[/cyan]\n")
 
-        # Call init programmatically
-        init(
+        # Call internal init function programmatically (NOT the CLI command)
+        success = _init_adapter_internal(
             adapter=adapter_type,
             project_path=str(proj_path),
             global_config=False,
         )
 
+        if not success:
+            console.print("[red]Failed to initialize adapter configuration[/red]")
+            raise typer.Exit(1) from None
+
+        # Check and install adapter-specific dependencies
+        _check_and_install_adapter_dependencies(adapter_type, console)
+
         console.print("\n[green]✓ Adapter configuration complete[/green]\n")
     else:
         console.print("[green]✓ Step 1/2: Adapter already configured[/green]\n")
@@ -432,16 +555,32 @@ def _check_existing_platform_configs(platforms: list, proj_path: Path) -> list[s
     for plat in platforms:
         try:
             if plat.name == "claude-code":
-                config_path = Path.home() / ".claude.json"
-                if config_path.exists():
-                    with open(config_path) as f:
+                # Check both new and old locations
+                new_config = Path.home() / ".config" / "claude" / "mcp.json"
+                old_config = Path.home() / ".claude.json"
+
+                is_configured = False
+
+                # Check new global location (flat structure)
+                if new_config.exists():
+                    with open(new_config) as f:
+                        config = json.load(f)
+                        if "mcp-ticketer" in config.get("mcpServers", {}):
+                            is_configured = True
+
+                # Check old location (nested structure)
+                if not is_configured and old_config.exists():
+                    with open(old_config) as f:
                         config = json.load(f)
                         projects = config.get("projects", {})
                         proj_key = str(proj_path)
                         if proj_key in projects:
                             mcp_servers = projects[proj_key].get("mcpServers", {})
                             if "mcp-ticketer" in mcp_servers:
-                                configured.append(plat.display_name)
+                                is_configured = True
+
+                if is_configured:
+                    configured.append(plat.display_name)
 
             elif plat.name == "claude-desktop":
                 if plat.config_path.exists():
