@@ -5,13 +5,13 @@ import sqlite3
 import threading
 from datetime import datetime, timedelta
 from pathlib import Path
-from typing import Any, Optional
+from typing import Any
 
 
 class TicketRegistry:
     """Persistent registry for tracking ticket IDs and their lifecycle."""
 
-    def __init__(self, db_path: Optional[Path] = None):
+    def __init__(self, db_path: Path | None = None):
         """Initialize ticket registry.
 
         Args:
@@ -27,7 +27,7 @@ class TicketRegistry:
         self._lock = threading.Lock()
         self._init_database()
 
-    def _init_database(self):
+    def _init_database(self) -> None:
         """Initialize database schema."""
         with sqlite3.connect(self.db_path) as conn:
             # Ticket registry table
@@ -130,10 +130,10 @@ class TicketRegistry:
         self,
         queue_id: str,
         status: str,
-        ticket_id: Optional[str] = None,
-        result_data: Optional[dict[str, Any]] = None,
-        error_message: Optional[str] = None,
-        retry_count: Optional[int] = None,
+        ticket_id: str | None = None,
+        result_data: dict[str, Any] | None = None,
+        error_message: str | None = None,
+        retry_count: int | None = None,
     ) -> None:
         """Update ticket operation status.
 
@@ -149,7 +149,7 @@ class TicketRegistry:
         with self._lock:
             with sqlite3.connect(self.db_path) as conn:
                 update_fields = ["status = ?", "updated_at = ?"]
-                values = [status, datetime.now().isoformat()]
+                values: list[Any] = [status, datetime.now().isoformat()]
 
                 if ticket_id is not None:
                     update_fields.append("ticket_id = ?")
@@ -179,7 +179,7 @@ class TicketRegistry:
                 )
                 conn.commit()
 
-    def get_ticket_info(self, queue_id: str) -> Optional[dict[str, Any]]:
+    def get_ticket_info(self, queue_id: str) -> dict[str, Any] | None:
         """Get ticket information by queue ID.
 
         Args:
@@ -202,7 +202,7 @@ class TicketRegistry:
                 return None
 
             columns = [desc[0] for desc in cursor.description]
-            ticket_info = dict(zip(columns, row))
+            ticket_info = dict(zip(columns, row, strict=False))
 
             # Parse JSON fields
             if ticket_info.get("ticket_data"):
@@ -236,7 +236,7 @@ class TicketRegistry:
             columns = [desc[0] for desc in cursor.description]
 
             for row in cursor.fetchall():
-                ticket_info = dict(zip(columns, row))
+                ticket_info = dict(zip(columns, row, strict=False))
 
                 # Parse JSON fields
                 if ticket_info.get("ticket_data"):
@@ -273,7 +273,7 @@ class TicketRegistry:
             columns = [desc[0] for desc in cursor.description]
 
             for row in cursor.fetchall():
-                ticket_info = dict(zip(columns, row))
+                ticket_info = dict(zip(columns, row, strict=False))
 
                 # Parse JSON fields
                 if ticket_info.get("ticket_data"):
@@ -306,7 +306,7 @@ class TicketRegistry:
             columns = [desc[0] for desc in cursor.description]
 
             for row in cursor.fetchall():
-                ticket_info = dict(zip(columns, row))
+                ticket_info = dict(zip(columns, row, strict=False))
 
                 # Parse JSON fields
                 if ticket_info.get("ticket_data"):
@@ -436,7 +436,7 @@ class TicketRegistry:
             columns = [desc[0] for desc in cursor.description]
 
             for row in cursor.fetchall():
-                recovery_info = dict(zip(columns, row))
+                recovery_info = dict(zip(columns, row, strict=False))
                 if recovery_info.get("recovery_data"):
                     recovery_info["recovery_data"] = json.loads(
                         recovery_info["recovery_data"]
